@@ -5,6 +5,7 @@ import logging
 import moto
 import os
 import pandas as pd
+import numpy as np
 from pandas.util.testing import assert_frame_equal
 import pyarrow as pa
 import pyarrow.parquet as pq
@@ -293,3 +294,19 @@ def setup_custom_redshift_columns_and_dataframe():
                                "colF": "BOOLEAN"}
 
     return (dataframe, custom_redshift_columns)
+
+
+def setup_custom_redshift_columns_and_dataframe_with_null():
+    """ Create a custom_redshift_columns dictionary that contains redshift column definitions and corresponding mock dataframe """
+    sample_data = {'colA': [1, 2, np.NaN], 'colB': ['DDD', None, 'FFF'],
+                   'colC': [pd.Timestamp('20131213 11:59:59.999999999'), None, pd.Timestamp('20131213 11:59:59.999999999')], 'colE': [7.5, 3.4, np.NaN]}
+
+    dataframe = pd.DataFrame(data=sample_data)
+
+    custom_redshift_columns = {"colA": "INTEGER",
+                               "colB": "VARCHAR",
+                               "colC": "TIMESTAMP",
+                               "colE": "DECIMAL(7,2)"
+                               }
+
+    return (dataframe, custom_redshift_columns)
